import { Configuration, App } from '@midwayjs/decorator';
import * as koa from '@midwayjs/koa';
import * as validate from '@midwayjs/validate';
import * as info from '@midwayjs/info';
import { join } from 'path';
// import { DefaultErrorFilter } from './filter/default.filter';
// import { NotFoundFilter } from './filter/notfound.filter';
import { ReportMiddleware } from './middleware/report.middleware';
// api文档
import * as swagger from '@midwayjs/swagger';
// 数据库
import * as typegoose from '@midwayjs/typegoose';
import * as Typegoose from '@typegoose/typegoose';
import { IMidwayApplication, IMidwayContainer } from '@midwayjs/core';

// import * as freeFrame from '../../free-midway-component/dist';
// import * as freeFrame from 'free-midway-component';

import { ResponseMiddleware } from './middleware/response.middleware';

@Configuration({
  imports: [
    // freeFrame,
    koa,
    validate,
    typegoose,
    {
      component: swagger,
      enabledEnvironment: ['local'],
    },
    {
      component: info,
      enabledEnvironment: ['local'],
    },
  ],
  importConfigs: [join(__dirname, './config')],
})
export class ContainerLifeCycle {
  @App()
  app: koa.Application;

  getApiUrl() {
    const path = this.app.getConfig()?.swagger?.swaggerPath;
    const port = this.app.getConfig()?.koa?.port;
    if (path) console.log(`api文档: http://127.0.0.1:${port}${path}/index.html`);
  }

  async onReady(container: IMidwayContainer, app: IMidwayApplication) {
    // add middleware
    app.useMiddleware([ReportMiddleware]);
    app.getMiddleware().insertLast(ResponseMiddleware);
    // add filter
    // this.app.useFilter([NotFoundFilter, DefaultErrorFilter]);
    // typegoose
    Typegoose.setGlobalOptions({
      schemaOptions: {
        id: true,
        toJSON: { getters: true, virtuals: true },
        toObject: { getters: true, virtuals: true },
      },
      options: { allowMixed: Typegoose.Severity.ALLOW },
    });
    this.getApiUrl();
  }
}
