import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import _ = require('lodash');
export class UserDTO {
  @ApiProperty({ example: '123', description: '名称' })
  @Rule(RuleType.string().required())
  name: string;

  @ApiProperty({
    example: '13089419810',
    type: 'string',
    description: '电话号码',
  })
  @Rule(RuleType.string().required().error(new Error('电话号码不能为空')))
  phone: string;

  @ApiProperty({
    example: '1203a-soeps',
    type: 'string',
    description: '微信openid',
  })
  @Rule(RuleType.string().allow())
  openid: string;
}

export class UserUpdateDTO {
  @ApiProperty({ example: '1234', description: '名称' })
  @Rule(RuleType.string().required())
  name: string;

  @ApiProperty({
    example: '13089419811',
    type: 'string',
    description: '电话号码',
  })
  @Rule(RuleType.string().required().error(new Error('电话号码不能为空')))
  phone: string;

  @ApiProperty({
    example: '12034a-soeps',
    type: 'string',
    description: '微信openid',
  })
  @Rule(RuleType.string().allow())
  openid: string;
}

export interface QueryVO {
  name: string;
  phone: string;
  openid: string;
}

export class FetchDTO {
  @ApiProperty({ example: 'ObjectId', description: '数据id' })
  id: string;
}

export class FetchVO {
  constructor(data: object) {
    this.id = _.get(data, '_id');
    this.name = _.get(data, 'name');
    this.phone = _.get(data, 'phone');
  }
  @ApiProperty({ description: 'id' })
  id: string;
  @ApiProperty({ description: '名称' })
  name: string;
  @ApiProperty({ description: '电话' })
  phone: string;
}
